@@ -1,5 +1,6 @@
 from crystally.core.lattice import *
 import numpy as np
+from crystally.core.vasp_tools import get_element_number_list
 
 
 __all__ = ("write_poscar", "read_poscar",)
@@ -20,7 +21,7 @@ def write_poscar(lattice: Lattice, file: str, poscar_description: str):
              "{:19.16f} {:19.16f} {:19.16f} \n" \
             .format(poscar_description, *tuple(lattice.vectors.flatten()))
 
-    element_numbers = lattice.get_element_number_list()
+    element_numbers = get_element_number_list(lattice)
     elements = [x[0] for x in element_numbers]
     numbers = [x[1] for x in element_numbers]
     for element in elements:
