@@ -5,10 +5,10 @@ from typing import Union
 
 
 class Atom:
-    """An entry within a crystal cell.
+    """An entry within a :class:`Lattice`.
 
     The Atom has three propertiers. An element from the periodic table, fractional coordinates in form of a
-    :class:`~crystal_creator.core.vectors.FractionalVector` and a sublattice identifier.
+    :class:`~crystally.core.vectors.FractionalVector` and a sublattice name.
 
     :param element: string of element name
     :param position: fractional position of the atom
@@ -104,6 +104,10 @@ class Lattice:
 
     @property
     def size(self):
+        """ Calculates the volume of the lattice.
+
+        :return: volume of lattice
+        """
         if self.vectors.ndim == 1:
             return np.linalg.norm(self.vectors)
         elif self.vectors.ndim == 2:
@@ -119,11 +123,20 @@ class Lattice:
     def sort(self, key=None, tolerance=None):
         """ Sort the lattice with a given key.
 
-        :param key: sorting argument. Either "element", "position", "position_from_origin", "sublattice" for sorting
-                    according to the corresponding :class:`.Atom` attribute or a function expression.
-        :param tolerance: tolerance parameter which will be used when sorting this lattice with another lattice
-                            (is not used when sorting with the keyword positions)
-        :return: the sorted Lattice
+        :param key: sorting argument which is used to sort the lattice. The following aruments can be used:
+
+                    1. "element" - will sort according to the atoms element names
+                    2. "position" - will sort according to the atoms absolute distance to the lattice origin
+                    3. "sublattice" - will sort according to the atoms sublattice name
+                    4. :class:`Lattice` - this will sort this lattice according to a different lattice. Equal atoms in
+                       this and the other lattice should then have the same position in the atoms lists. Element and
+                       Sublattice of the atoms are compared for equality. The position is compared with a tolerance in
+                       angstrom. This means that if the atoms are closer together than the tolerance, their position
+                       is treated as equal.
+
+        :param tolerance: tolerance parameter which will be used when sorting this lattice with another lattice. If
+                          None is specified the default value of constants.ABS_VEC_COMP_TOL is used.
+        :return: nothing
         """
         if key is None:
             self.atoms.sort(key=lambda atom: (atom.element, atom.sublattice, atom.position))
@@ -140,13 +153,15 @@ class Lattice:
         return None
 
     def find(self, element=None, sublattice=None, position=None, tolerance=None, first=False):
-        """ Get the atoms of the lattice with the specified element and/or sublattice
+        """ Search the atom list according to the specified parameters.
 
-        :param element: element name of the atoms to get - ignored if not specified or None
-        :param sublattice: sublattice name of the atoms to get - ignored if not specified or None
-        :param position: position of the atoms to get (range comparison is done with constants.FRAC_VEC_COMP_TOL)
-                        - ignored if not specified or None
-        :return: list of :class:`Atoms <.Atom>`
+        :param element: element name of the atoms to get
+        :param sublattice: sublattice name of the atoms to get
+        :param position: position of the atoms to get within a tolerance (can be specified)
+        :param tolerance: tolerance of positional search in angstrom.
+        :param first: If set to `True` the first found atom is returned.
+        :return: list of :class:`Atoms <.Atom>` or :class:`Atoms <.Atom>` if first=True or `None` if no atoms satisfy
+                 the criteria.
         """
         def element_cond(atom):
             return True if element is None else atom.element == element
@@ -172,15 +187,36 @@ class Lattice:
             return list(found_atoms)
 
     def remove(self, atom: Atom):
-        index = self.index(atom.position, tolerance=1e-10)
-        del(self[index])
-        return None
+        """ Removes an atom from the atom list.
+
+        :param atom: :class:`Atoms <.Atom>` that should be removed. This atom has to come from the atom list in the
+                     first place.
+        :return: None
+        """
+        for i, a in enumerate(self):
+            if id(a) == id(atom):
+                del(self[i])
+                break
+        else:
+            raise ValueError("The specified atom is not in the atom list of this lattice.")
 
     def to_cartesian(self, position):
+        """ Translates fractional coordinates to cartesian coordinates.
+
+        :param position: fractional coordinates
+        :return: cartesian coordinates
+        """
         position = getattr(position, "position", position)
         return self.vectors.dot(np.array(position))
 
     def to_fractional(self, position, periodic=True):
+        """ Translates cartesian coordinates to fractional coordinates.
+
+        :param position: cartesian coordinates
+        :param periodic: if periodic is set to `True`. The fractional coordinates are translated
+                         to a value between 0 and 1.
+        :return: fractional coordinates
+        """
         frac_position = np.linalg.inv(self.vectors) @ position
         if periodic:
             return FractionalVector(frac_position).value
@@ -188,12 +224,13 @@ class Lattice:
             return frac_position
 
     def get_in_radius(self, center: Union[np.array, list, Atom], max_radius, min_radius=0.0):
-        """ Fetch a :class:`.Atom` from the stom list at the provided position
+        """ Get all :class:`.Atom` that are in range to a provided position.
 
-        :param min_radius: minimal radius, that is searched
-        :param max_radius: maximal radius, that is seached
-        :param center: Position of the searched :class:`.Atom`
-        :return: :class:`.Atom` object
+        :param center: Search center in fractional coordinates. This can either be a list of coordinates or a :class:`.Atom`.
+        :param max_radius: maximal radius in angstrom, that is searched
+        :param min_radius: minimal radius in angstrom, that is searched. Default is 0 angstrom.
+
+        :return: List of :class:`.Atom`
         """
 
         def condition(atom):
@@ -203,11 +240,11 @@ class Lattice:
         return atom_list
 
     def index(self, position, tolerance=1e-3):
-        """ Get the index of the :class:`.Atom` at the provided position
+        """ Get the index within the atom list of the :class:`.Atom` at the provided position
 
         :param position: Position or Atom whose index is searched for
-        :param tolerance: Tolerance of fractional coordinates
-        :return: int, index of :class:`.Atom`
+        :param tolerance: Tolerance in angstrom
+        :return: index of :class:`.Atom`
         """
         position = getattr(position, "position", position)
         position = np.array(getattr(position, "value", position))
@@ -234,49 +271,11 @@ class Lattice:
         [sublattice_names.add(x.sublattice) for x in self.atoms]
         return list(sublattice_names)
 
-    def get_element_number_list(self):
-        """Get a two dimensional list with the sort order of the elements within the lattice.
-
-        The first column specifies the element name and the second column the number of adjacent atoms with this
-        element. This information can be used for VASP Input files.
-        For instance if the sort order of the atoms is as follows:
-
-        X, X, Y, Y, Y, X, X
-
-        (where X and Y are the elements of the atoms)
-        the function would return the following table:
-
-        =============  =============================
-        Element Name   Number of repeating elements
-        =============  =============================
-        X              2
-        Y              4
-        X              2
-        =============  =============================
-
-        :return: two dimensional list - the first column is an int, the second a string
-
-        Examples
-        --------
-        >>> #lattice = generate_from_crystal(ceria(),2,2,2).sort("position")
-        >>> #print(lattice.get_element_number_list())
-        [['Ce', 1], ['O', 1], ['Ce', 3], ['O', 7]]
-        """
-        element_number_list = []
-        for atom in self.atoms:
-            if not element_number_list:
-                element_number_list.append([atom.element, 1])
-            elif element_number_list[-1][0] == atom.element:
-                element_number_list[-1][1] += 1
-            else:
-                element_number_list.append([atom.element, 1])
-        return element_number_list
-
     def distance(self, position1, position2, periodic=True):
         """ Get the distance between two points
 
-        :param position1: fractional coordinate as vector shaped container
-        :param position2: fractional coordinate as vector shaped container
+        :param position1: fractional coordinate as list or atom
+        :param position2: fractional coordinate as list or atom
         :param periodic: bool, flag that indicates if the distance should be calculated under consideration of
                                 periodic boundaries
         :return: float, distance in Angstrom
@@ -298,7 +297,15 @@ class Lattice:
         return np.sqrt(diff_vector_cartesian.dot(diff_vector_cartesian))
 
     def increase_distance_rel(self, center, position, rel_increase):
+        """ Function to easily manipulate lattices. A center and second position need to be provided. The second
+        position is then shifted away from the center position by a provided percentage. The new position is then returned.
+        Mind that no variables are changed by this function.
 
+        :param center: fractional coordinates of the center position. Can be a list of coordinates or a :class:`.Atom`.
+        :param position: fractional coordinates of the second position. Can be a list of coordinates or a :class:`.Atom`.
+        :param rel_increase: distance increase in percent
+        :return: new position as :class:`~crystally.core.vectors.FractionalVector`
+        """
         # First check if atoms were passed to the function
         center = getattr(center, "position", center)
         position = getattr(position, "position", position)
@@ -321,12 +328,30 @@ class Lattice:
         return FractionalVector(np.linalg.inv(self.vectors).dot(new_position))
 
     def increase_distance_abs(self, center, position, abs_increase):
+        """ Function to easily manipulate lattices. A center and second position need to be provided. The second
+        position is then shifted away from the center position by a provided value. The new position is then returned.
+        Mind that no variables are changed by this function.
+
+        :param center: fractional coordinates of the center position. Can be a list of coordinates or a :class:`.Atom`.
+        :param position: fractional coordinates of the second position. Can be a list of coordinates or a :class:`.Atom`.
+        :param abs_increase: Shift in angstrom
+        :return: new position as :class:`~crystally.core.vectors.FractionalVector`
+        """
         distance = self.distance(center, position)
         rel_distance = abs_increase/distance
         return self.increase_distance_rel(center, position, rel_distance)
 
     def diff(self, other, tolerance=None):
-        """Compares the Atoms in this and the other lattice"""
+        """ Find the atomic differences bewteen this and another lattice. Atoms are compared according to element
+            sublattice and position. Mind that the fractional position of this and the other lattice are converted
+            to cartesian coordinates with the vectors of this lattice.
+
+        :param other: other :class:`.Lattice`.
+        :param tolerance: tolerance in angstrom with which the atoms position are compared.
+        :return: tuple with two lists, the first list consists of the atoms that were in this lattice, but were not
+                 found in the other lattice. The second list contains the atoms that were in the other lattice, but not
+                 found in this lattice.
+        """
 
         if not tolerance:
             tolerance = const.ABS_VEC_COMP_TOL
@@ -344,25 +369,6 @@ class Lattice:
 
         return self_not_found, other_not_found
 
-    def grid_atoms(self, grid_step):
-
-        def to_grid(self, position, round_func):
-            position = self.vectors @ position
-            return tuple(int(x) for x in round_func(np.round(position / grid_step, 10)))
-
-        grid_size = to_grid(self, np.array([1, 1, 1]), np.ceil)
-        print(grid_size)
-        print(np.round(self.vectors @ np.array([1, 1, 1]) / grid_step, 10))
-
-        grid = [[[[] for _ in range(grid_size[2])]
-                     for _ in range(grid_size[1])]
-                     for _ in range(grid_size[0])]
-
-        for atom in self:
-            x, y, z = to_grid(self, atom.position, np.floor)
-            grid[x][y][z].append(atom)
-        return grid
-
     def _sort_with_other_lattice(self, other, tolerance=None):
         if not tolerance:
             tolerance = const.ABS_VEC_COMP_TOL
@@ -387,11 +393,52 @@ class Lattice:
         return True
 
     @staticmethod
-    def from_lattice(lattice, size_x=1, size_y=1, size_z=1):
-        new_lattice =  expand_lattice(lattice, size_x, size_y, size_z)
+    def from_lattice(lattice, size_x: int = 1, size_y: int = 1, size_z: int = 1):
+        """ Create a new lattice with an already existing one. You can also provide size values to expand the lattice.
+
+        :param lattice: the :class:`.Lattice` on which the new lattice is based on
+        :param size_x: int, multiplier by which the base lattice is expanded in x direction
+        :param size_y: int, see size_x
+        :param size_z: int, see size_x
+        :return: new :class:`.Lattice`
+        """
+
+        new_lattice_size = np.array([size_x, size_y, size_z])
+        new_lattice_positions = []
+
+        def reorientate_position(pos, x, y, z): return FractionalVector((pos + np.array([x, y, z])) / new_lattice_size)
+
+        lattice_expansion = ((x, y, z) for x in range(size_x) for y in range(size_y) for z in range(size_z))
+        new_lattice_positions += [Atom(element=atom.element,
+                                       sublattice=atom.sublattice,
+                                       position=reorientate_position(atom.position.value, *coord))
+                                  for coord in lattice_expansion for atom in lattice.atoms]
+
+        lattice_vectors = lattice.vectors * new_lattice_size
+        new_lattice = Lattice(lattice_vectors, new_lattice_positions)
         new_lattice.sort("element")
         return new_lattice
 
+    @staticmethod
+    def grid_atoms(lattice, grid_step):
+
+        def to_grid(lattice, position, round_func):
+            position = lattice.vectors @ position
+            return tuple(int(x) for x in round_func(np.round(position / grid_step, 10)))
+
+        grid_size = to_grid(lattice, np.array([1, 1, 1]), np.ceil)
+        print(grid_size)
+        print(np.round(lattice.vectors @ np.array([1, 1, 1]) / grid_step, 10))
+
+        grid = [[[[] for _ in range(grid_size[2])]
+                     for _ in range(grid_size[1])]
+                     for _ in range(grid_size[0])]
+
+        for atom in lattice:
+            x, y, z = to_grid(lattice, atom.position, np.floor)
+            grid[x][y][z].append(atom)
+        return grid
+
 
 def concat_lattices(lattice1: Lattice, lattice2: Lattice, direction: int):
     for i in range(lattice1.vectors.shape[0]):
@@ -418,19 +465,3 @@ def concat_lattices(lattice1: Lattice, lattice2: Lattice, direction: int):
         new_lattice.atoms.append(new_atom)
 
     return new_lattice
-
-
-def expand_lattice(lattice, size_x, size_y, size_z):
-    supercell_size = np.array([size_x, size_y, size_z])
-    supercell_positions = []
-
-    def reorientate_position(pos, x, y, z): return FractionalVector((pos + np.array([x, y, z])) / supercell_size)
-
-    lattice_expansion = ((x, y, z) for x in range(size_x) for y in range(size_y) for z in range(size_z))
-    supercell_positions += [Atom(element=atom.element,
-                                 sublattice=atom.sublattice,
-                                 position=reorientate_position(atom.position.value, *coord))
-                            for coord in lattice_expansion for atom in lattice.atoms]
-
-    lattice_vectors = lattice.vectors * supercell_size
-    return Lattice(lattice_vectors, supercell_positions)
